Documentation
¶
Index ¶
- Constants
- Variables
- func AlbumToArray() []string
- func CategoriesAdd(id string, desc string)
- func CategoriesDelete(row int)
- func CategoriesGet()
- func CategoriesToArray() []string
- func CategoriesUpdate(row int, id string, desc string)
- func CategoriesWhereUsed(cat string) int
- func CategoriesWriteStub(withinventory bool) string
- func ComparePasswords(hashedPwd string, plainPwd []byte) bool
- func DataStore(file string) fyne.URI
- func DaysAdd(day string, desc string, dow int)
- func DaysDelete(row int)
- func DaysGet()
- func DaysUpdate(row int, day string, desc string, dow int)
- func Decrypt(text string, secret string) string
- func DecryptFile(filePathIn, filePathOut string) error
- func DeleteBucket(bucket, id string) error
- func DeleteNatsMessage(seq uint64)
- func Edit(action string, value string) bool
- func Encrypt(text string, secret string) string
- func EncryptFile(filePathIn, filePathOut string) error
- func EraseMessages(queue string)
- func GetBucket(bucket, id, station string) []byte
- func GetBucketSize(bucket, id string) uint64
- func GetLangs(c string) string
- func HashAndSalt(pwd []byte) string
- func HoursAdd(id string, desc string)
- func HoursDelete(row int)
- func HoursGet()
- func HoursUpdate(row int, id string, desc string)
- func InventoryAdd(category string, artist string, song string, album string, songlength int, ...) int
- func InventoryDelete(row int)
- func InventoryGet()
- func InventoryUpdate(row int, category string, artist string, song string, album string, ...)
- func InventoryUpdateRNDORDER()
- func LoadHashWithDefault(filename string, password string) (string, bool)
- func NewNatsJS() error
- func NewPGSQL() error
- func PDFCategory(rn, stationid string)
- func PDFCategoryByID() []core.Row
- func PDFDays(rn, stationid string)
- func PDFDaysByDay() []core.Row
- func PDFHours(rn, stationid string)
- func PDFHoursByHour() []core.Row
- func PDFInventory(rn, cat, stationid string)
- func PDFInventoryByCategory(cat string) []core.Row
- func PDFSchedule(rn, stationid string)
- func PDFScheduleByDay() []core.Row
- func PDFTraffic(rn, stationid string)
- func PDFTrafficByAlbum() []core.Row
- func PDFTrafficPageHeader(rn string) core.Row
- func ParseURL(urlStr string) *url.URL
- func PutBucket(bucket string, id string, data []byte) error
- func ReceiveMESSAGE()
- func ReceiveONAIRMP3()
- func SaveHash(filename string, hash string) (string, bool)
- func ScheduleAdd(days string, hours string, position string, categories string, spinstoplay int)
- func ScheduleCopy(dayfrom, dayto string)
- func ScheduleDelete(row int)
- func ScheduleGet()
- func ScheduleUpdate(row int, days string, hours string, position string, categories string, ...)
- func Send(subject, m, alias string) bool
- func SendONAIRmp3(m string)
- func SendONAIRmp4(m string)
- func SetupDetails(queue string, age string)
- func SetupNATS()
- func TestBucket(bucket, id string) bool
- func ToPDF(reportname, stationid string)
- type CategoriesStruct
- type CommandStore
- type DateTimePicker
- type DaysStruct
- type DeviceStore
- type HoursStruct
- type InventoryStruct
- type MessageStore
- type MyTheme
- func (m MyTheme) Color(name fyne.ThemeColorName, variant fyne.ThemeVariant) color.Color
- func (m MyTheme) Font(style fyne.TextStyle) fyne.Resource
- func (m MyTheme) Icon(name fyne.ThemeIconName) fyne.Resource
- func (m MyTheme) SetIcon(name fyne.ThemeIconName, variant fyne.ThemeVariant)
- func (m MyTheme) Size(name fyne.ThemeSizeName) float32
- type Natsjs
- type NatsjsREPORT
- type SQLconn
- type ScheduleStruct
Constants ¶
const BUFFER_SIZE int = 4096
todo: use circl from cloudfare to encrypt data post quantum crystals-kyber, crystals-dilithium, sphincs=, FALCON
const IV_SIZE int = 16
const MySecret string = "abd&1*~#^2^#s0^=)^^7%c34" // must be 24 characters
const Password = "123456" // default password shipped with app
default gui password
Variables ¶
var AlbumArray []string
var CategoriesStore = make(map[int]CategoriesStruct)
var CategoryArray []string
var DBClientcert = "" /* 1042-byte string literal not displayed */
var DBClientkey = "" /* 1732-byte string literal not displayed */
var DBaddress = "db.newhorizons3000.org:5432/radio?sslmode=verify-ca"
var DBaddress = "localhost:5432/radio"
var DBpassword = "postgres"
var DBuser = "postgres"
var Dark = 0
var DarkButton = color.RGBA{187, 188, 201, 32}
var DarkButton = color.RGBA{162, 168, 250, 64}
var DarkDisabled = color.RGBA{187, 188, 201, 64}
var DarkFocus = color.RGBA{187, 188, 201, 64}
var DarkHover = color.RGBA{187, 188, 201, 64}
var DarkHyperlink = color.RGBA{187, 188, 201, 255}
var DarkInputBackground = color.RGBA{187, 188, 201, 32}
var DarkInputBorder = color.RGBA{187, 188, 201, 64}
var DarkPlaceholder = color.RGBA{187, 188, 201, 220}
var DarkPressed = color.RGBA{187, 188, 201, 220}
var DarkPrimary = color.RGBA{187, 188, 201, 255}
var DarkScrollBar = color.RGBA{187, 188, 201, 64}
var DarkSelection = color.RGBA{187, 188, 201, 128}
var DarkSeparator = color.RGBA{187, 188, 201, 64}
var DarkShadow = color.RGBA{187, 188, 201, 64}
var DaysStore = make(map[int]DaysStruct)
var FyneApp fyne.App
var FyneCategoryList fyne.Widget
var FyneDaysList fyne.Widget
var FyneDeviceList fyne.Widget
var FyneDeviceWin fyne.Window
var FyneFilter bool
var FyneFilterDevices bool
var FyneInventoryList fyne.Widget
var FyneInventoryWin fyne.Window
var FyneMainWin fyne.Window
var FyneMessageList fyne.Widget
var FyneMessageWin fyne.Window
var FyneScheduleList fyne.Widget
var HoursStore = make(map[int]HoursStruct)
var InventoryStore = make(map[int]InventoryStruct)
var KeyAes = []byte{35, 46, 57, 24, 85, 35, 24, 74, 87, 35, 88, 98, 66, 32, 14, 05} // must be 16 bytes
default encryption
var KeyHmac = []byte{36, 45, 53, 21, 87, 35, 24, 74, 87, 35, 88, 98, 66, 32, 14, 05} // must be 16 bytes
var Light = 1
var LightButton = color.RGBA{129, 137, 252, 250}
var LightDisabled = color.RGBA{129, 137, 252, 64}
var LightFocus = color.RGBA{129, 137, 252, 64}
var LightHover = color.RGBA{129, 137, 252, 1}
var LightHyperlink = color.RGBA{129, 137, 252, 1}
var LightInputBackground = color.RGBA{129, 137, 252, 32}
var LightInputBorder = color.RGBA{129, 137, 252, 250}
var LightPlaceholder = color.RGBA{129, 137, 252, 220}
var LightPressed = color.RGBA{129, 137, 252, 220}
var LightPrimary = color.RGBA{129, 137, 252, 255}
var LightScrollBar = color.RGBA{129, 137, 252, 250}
var LightSelection = color.RGBA{129, 137, 252, 200}
var LightSeparator = color.Black
var LightShadow = color.RGBA{129, 137, 252, 64}
var LoggedOn bool
var MessageToSend string
var fyneFilterFound = false
var MyLangs = map[string]string{}/* 438 elements not displayed */
eng esp cmn
var NATS = &Natsjs{}
var NATSREPORT = &NatsjsREPORT{}
var NATSSTREAM = "NATS"
var NatsAdmin = "natsadmin"
defaults
var NatsAlias string
var NatsCaroot = "" /* 1448-byte string literal not displayed */
var NatsClientcert = "" /* 1538-byte string literal not displayed */
var NatsClientkey = "" /* 1706-byte string literal not displayed */
var NatsMessages = make(map[int]MessageStore)
var NatsMessagesIndex = make(map[string]bool)
var NatsMessagesIndexDevice = make(map[string]bool)
var NatsMessagesDevice = make(map[int]MessageStore)
var NatsMsgMaxAge string
var NatsNodeUUID string
var NatsQueueDurable = "snatsdurable"
var NatsQueuePassword = "987654321098765432109876"
var NatsServer = "nats://nats.newhorizons3000.org:4222"
var NatsUser = "natsoperator"
var NatsUserAuthorizations = "natsauthorizations"
var NatsUserAuthorizationsPassword = "PASSWORD"
var NatsUserCommands = "natscommands"
var NatsUserCommandsPassword = "PASSWORD"
var NatsUserDevices = "natsdevices"
var NatsUserDevicesPassword = "PASSWORD"
var NatsUserEvents = "natsevents"
var NatsUserEventsPassword = "PASSWORD"
var NatsUserPassword = "hjscr44iod"
var PasswordHash string
var PreferedLanguage string
var Retro = 2
var RetroButton = color.RGBA{116, 207, 103, 250}
var RetroDisabled = color.RGBA{116, 207, 103, 64}
var RetroFocus = color.RGBA{116, 207, 103, 64}
var RetroHover = color.RGBA{116, 207, 103, 1}
var RetroHyperlink = color.RGBA{116, 207, 103, 1}
var RetroInputBackground = color.RGBA{116, 207, 103, 32}
var RetroInputBorder = color.RGBA{116, 207, 103, 250}
var RetroPlaceholder = color.RGBA{116, 207, 103, 255}
var RetroPressed = color.RGBA{116, 207, 103, 220}
var RetroPrimary = color.RGBA{116, 207, 103, 255}
var RetroScrollBar = color.RGBA{116, 207, 103, 250}
var RetroSelection = color.RGBA{116, 207, 103, 200}
var RetroSeparator = color.Black
var RetroShadow = color.RGBA{116, 207, 103, 64}
var SQL = &SQLconn{}
* The following fields need to be modified for your production * Environment to provide maximum security * * These fields are meant to be distributed at compile time and * editable in the gui. *
var ScheduleCategory int
var ScheduleStore = make(map[int]ScheduleStruct)
var Selected = 0
var SelectedCategory int
var SelectedDay int
var SelectedHour int
var SelectedInventory int
var TrafficAlbum = ""
var TrafficEnd = "YYYY-MM-DD 23:59:59"
var TrafficStart = "YYYY-MM-DD 00:00:00"
Functions ¶
func AlbumToArray ¶
func AlbumToArray() []string
func CategoriesAdd ¶
func CategoriesDelete ¶
func CategoriesDelete(row int)
func CategoriesGet ¶
func CategoriesGet()
func CategoriesToArray ¶
func CategoriesToArray() []string
func CategoriesUpdate ¶
func CategoriesWhereUsed ¶
func CategoriesWriteStub ¶
func ComparePasswords ¶
validate password
func DaysDelete ¶
func DaysDelete(row int)
func DecryptFile ¶
func DeleteBucket ¶
func DeleteNatsMessage ¶
func DeleteNatsMessage(seq uint64)
func EncryptFile ¶
func EraseMessages ¶
func EraseMessages(queue string)
func GetBucketSize ¶
func HoursDelete ¶
func HoursDelete(row int)
func HoursUpdate ¶
func InventoryAdd ¶
func InventoryDelete ¶
func InventoryDelete(row int)
func InventoryGet ¶
func InventoryGet()
func InventoryUpdate ¶
func InventoryUpdateRNDORDER ¶
func InventoryUpdateRNDORDER()
func LoadHashWithDefault ¶
create and load hash
func PDFCategory ¶
func PDFCategory(rn, stationid string)
func PDFCategoryByID ¶
func PDFDaysByDay ¶
func PDFHoursByHour ¶
func PDFInventory ¶
func PDFInventory(rn, cat, stationid string)
func PDFInventoryByCategory ¶
func PDFSchedule ¶
func PDFSchedule(rn, stationid string)
func PDFScheduleByDay ¶
func PDFTraffic ¶
func PDFTraffic(rn, stationid string)
func PDFTrafficByAlbum ¶
func PDFTrafficPageHeader ¶
func ReceiveMESSAGE ¶
func ReceiveMESSAGE()
func ReceiveONAIRMP3 ¶
func ReceiveONAIRMP3()
func ScheduleAdd ¶
func ScheduleCopy ¶
func ScheduleCopy(dayfrom, dayto string)
func ScheduleDelete ¶
func ScheduleDelete(row int)
func ScheduleGet ¶
func ScheduleGet()
func ScheduleUpdate ¶
func SendONAIRmp3 ¶
func SendONAIRmp3(m string)
func SendONAIRmp4 ¶
func SendONAIRmp4(m string)
func SetupDetails ¶
func TestBucket ¶
Types ¶
type CategoriesStruct ¶
type CommandStore ¶
type DateTimePicker ¶
type DateTimePicker struct {
widget.BaseWidget
OnActioned func(bool)
// contains filtered or unexported fields
}
func NewDatePicker ¶
func NewDateTimePicker ¶
func (*DateTimePicker) CreateRenderer ¶
func (dtp *DateTimePicker) CreateRenderer() fyne.WidgetRenderer
type DaysStruct ¶
type DeviceStore ¶
type DeviceStore struct {
DSiduuid string // message id
DSalias string // alias
DShostname string // hostname
DSipadrs string // ip address
DSmacid string // macids
DSnodeuuid string // unique id
DSmessage string // message payload
DSdate string // message date
DSsubject string // message subject
DSos string // device os
DSsequence uint64 // consumer sequence for secure delete
DSelementid int // order in array
}
type HoursStruct ¶
type InventoryStruct ¶
type InventoryStruct struct {
Row int // rowid
Category string // category
Artist string // artist
Song string // song
Album string // Album
Songlength int // song length
Rndorder string // assigned weekly
Startson string //
Expireson string
Lastplayed string
Dateadded string
Spinstoday int // cleared daily at day reset
Spinsweek int // spins weekly at week reset
Spinstotal int // total spins
Sourcelink string // link to relevant source
}
type MessageStore ¶
type MessageStore struct {
MSiduuid string // message id
MSalias string // alias
MShostname string // hostname
MSipadrs string // ip address
MSmacid string // macids
MSmessage string // message payload
MSnodeuuid string // unique id
MSdate string // message date
MSsubject string // message subject
MSos string // device os
MSsequence uint64 // consumer sequence for secure delete
MSelementid int // order in array
}
type MyTheme ¶
type MyTheme struct{}
func (MyTheme) Color ¶
func (m MyTheme) Color(name fyne.ThemeColorName, variant fyne.ThemeVariant) color.Color
func (MyTheme) SetIcon ¶
func (m MyTheme) SetIcon(name fyne.ThemeIconName, variant fyne.ThemeVariant)
type NatsjsREPORT ¶
Click to show internal directories.
Click to hide internal directories.